#include <SDL/SDL_ttf.h>

#include "cCountdown.h"
#include "cGame.h"
#include "constants.h"
#include "functions.h"
#include "globals.h"

int cCountdown::logic() {
    if (SDL_GetTicks() - startTime >= steps * 5) {
        return 1;
    }

    return 0;
}

int cCountdown::render(cGame* curGM) {
    curGM->render();

    int progression = (SDL_GetTicks() - startTime) / steps;

    int dY = 70;

    const SDL_PixelFormat& fmt = *(screen->format);
    SDL_Surface* tS = SDL_CreateRGBSurface(SDL_SWSURFACE, SCR_W, SCR_H, fmt.BitsPerPixel, fmt.Rmask, fmt.Gmask, fmt.Bmask, fmt.Amask);
    SDL_FillRect(tS, NULL, SDL_MapRGBA(tS->format, 255, 255, 255, 0));
    SDL_SetAlpha(tS, SDL_SRCALPHA, 200 - ((SDL_GetTicks() - startTime) / 2500.0 * 200));
    applySurface(tS, screen, 0, 0);
    SDL_FreeSurface(tS);

    switch (progression) {
        case 0:
            applySurface(f, screen, (SCR_W - f->w) / 2, (SCR_H - f->h) / 2 - dY);
            break;
        case 1:
            applySurface(tr, screen, (SCR_W - tr->w) / 2, (SCR_H - tr->h) / 2 - dY);
            break;
        case 2:
            applySurface(tw, screen, (SCR_W - tw->w) / 2, (SCR_H - tw->h) / 2 - dY);
            break;
        case 3:
            applySurface(o, screen, (SCR_W - o->w) / 2, (SCR_H - o->h) / 2 - dY);
            break;
        default:
            applySurface(g, screen, (SCR_W - g->w) / 2, (SCR_H - g->h) / 2 - dY);
            break;
    }

    return 0;
}

cCountdown::cCountdown() {
    f = TTF_RenderText_Blended(fBig, "4", clrBlack);
    tr = TTF_RenderText_Blended(fBig, "3", clrBlack);
    tw = TTF_RenderText_Blended(fBig, "2", clrBlack);
    o = TTF_RenderText_Blended(fBig, "1", clrBlack);
    g = TTF_RenderText_Blended(fBig, "GO!", clrBlack);

    startTime = SDL_GetTicks();

    steps = 500;
}

cCountdown::~cCountdown() {
    delete f;
    delete tr;
    delete tw;
    delete o;
    delete g;
}
