#include <SDL/SDL.h>
#include <sstream>
#include <string>

#include "button.h"
#include "cGame.h"
#include "cSnake.h"
#include "functions.h"
#include "globals.h"

int cGame::logic(Uint8* keyState, int mX, int mY, Uint8 mouseState) {
    int retVal = 0;
    eDirection dir;

    if (keyState[SDLK_ESCAPE] || bPause->logic(mX, mY, mouseState) == B_CLICK) {
        retVal = 1;
    }

    if (keyState[SDLK_UP]) {
        dir = top;
    } else if (keyState[SDLK_DOWN]) {
        dir = bottom;
    } else if (keyState[SDLK_LEFT]) {
        dir = left;
    } else if (keyState[SDLK_RIGHT]) {
        dir = right;
    } else {
        dir = snake->getDir();
    }

    int tSnakeLogic = snake->logic(dir, false);

    if (tSnakeLogic == 1 || tSnakeLogic == 3) {
        retVal = 2;
    }

    targetMan->logic(snake);

    return retVal;
}

int cGame::render() {
    // Score
    SDL_Surface* tSurf;
    SDL_Surface* tSurf2;
    std::string tString;
    std::stringstream ss;

    ss << *scorePtr;
    tString = ss.str();

    int d = 10;

    tSurf = TTF_RenderText_Shaded(fSpecial, tString.c_str(), clrBlack, clrWhite);
    applySurface(tSurf, screen, 500 - tSurf->w, d);

    tSurf2 = TTF_RenderText_Shaded(fTag, "Score:", clrBlack, clrWhite);
    applySurface(tSurf2, screen, 500 - tSurf->w - tSurf2->w, d + tSurf->h - tSurf2->h - 20);

    SDL_FreeSurface(tSurf);
    SDL_FreeSurface(tSurf2);

    SDL_Rect t;
    t.x = 10;
    t.y = 10;
    t.w = 30;
    t.h = 30;

    // Draw borders
    if (true) { // snake->gWalls()
        SDL_Rect t;
        t.x = 3;
        t.y = 100 + 3;
        t.w = 4 + 3 + 480 + 3 + 4; // 480 + 3 + 3;
        t.h = 4 + 3 + 480 + 3 + 4;

        SDL_FillRect(screen, &t, SDL_MapRGB(screen->format, 0, 0, 0));

        t.x = 3 + 4;
        t.y = 100 + 3 + 4;
        t.w = 3 + 480 + 3;
        t.h = 3 + 480 + 3;

        SDL_FillRect(screen, &t, SDL_MapRGB(screen->format, 255, 255, 255));
    }

    snake->render();

    bPause->render();

    targetMan->render();

    return 0;
}

int cGame::pause() {
    snake->pause();

    return 0;
}

int cGame::resume() {
    snake->resume();

    return 0;
}

cGame::cGame(int* score, int userDiff, int userWalls) {
    snake = new cSnake(userDiff, userWalls, 2);
    bPause = new cButton("Pauze", 20, 10, false, fSpecial, B_VISIBLE, B_STANDARD);

    scorePtr = score;

    diff = userDiff;
    walls = userWalls;

    targetMan = new cTargetMan(score, userDiff);
}

cGame::~cGame() {
    delete snake;
    delete bPause;
    delete targetMan;
}
