#include <SDL/SDL_ttf.h>
#include <string>
#include <sstream>

#include "cGameOver.h"
#include "constants.h"
#include "functions.h"
#include "globals.h"

int cGameOver::logic(int mX, int mY, Uint8 mouseState, std::string* tS) {
    if (bBack->logic(mX, mY, mouseState) == B_CLICK) {
        *tS = input->gInput();
        return 1;
    }

    SDL_Event tEvent;
    while (SDL_PollEvent(&tEvent)) {
        input->logic(&tEvent);
    }

    return 0;
}

int cGameOver::render(cGame* curGM) {
    curGM->render();
    if (SDL_GetTicks() - startTime <= 4000) {
        const SDL_PixelFormat& fmt = *(screen->format);
        SDL_Surface* tS = SDL_CreateRGBSurface(SDL_SWSURFACE, SCR_W, SCR_H, fmt.BitsPerPixel, fmt.Rmask, fmt.Gmask, fmt.Bmask, fmt.Amask);
        SDL_FillRect(tS, NULL, SDL_MapRGBA(tS->format, 255, 255, 255, 0));
        SDL_SetAlpha(tS, SDL_SRCALPHA, ((SDL_GetTicks() - startTime) / 4000.0 * 255));
        applySurface(tS, screen, 0, 0);
        SDL_FreeSurface(tS);
    } else {
        const SDL_PixelFormat& fmt = *(screen->format);
        SDL_Surface* tS = SDL_CreateRGBSurface(SDL_SWSURFACE, SCR_W, SCR_H, fmt.BitsPerPixel, fmt.Rmask, fmt.Gmask, fmt.Bmask, fmt.Amask);
        SDL_FillRect(tS, NULL, SDL_MapRGBA(tS->format, 255, 255, 255, 0));
        SDL_SetAlpha(tS, SDL_SRCALPHA, 255);
        applySurface(tS, screen, 0, 0);
        SDL_FreeSurface(tS);
    }

    applySurface(sGameOver, screen, (SCR_W - sGameOver->w) / 2, 200);
    applySurface(sScore, screen, (SCR_W / 2), 350 - 80);
    applySurface(sScoreTag, screen, (SCR_W / 2) - sScoreTag->w, 390 - 80);

    input->render(screen, 140, 400);

    SDL_Surface* t;
    t = TTF_RenderText(fTag, "Typ je naam:", clrBlack, clrWhite);
    applySurface(t, screen, 140 - t->w, 416);

    bBack->render();

    return 0;
}

cGameOver::cGameOver(int score) {
    sGameOver = TTF_RenderText_Blended(fSpecial, "Game over!", clrBlack);
    sScoreTag = TTF_RenderText_Blended(fTagP, "Score:", clrBlack);

    std::string tString;
    std::stringstream ts;

    ts << score;
    tString = ts.str();

    sScore = TTF_RenderText_Blended(fSpecial, tString.c_str(), clrBlack);

    bBack = new cButton("Terug", 200, 500, false, fSpecial, B_VISIBLE, B_STANDARD);

    input = new cStringInput(fNormal, 0, 0, 0);

    startTime = SDL_GetTicks();
}

cGameOver::~cGameOver() {
    SDL_FreeSurface(sGameOver);
    SDL_FreeSurface(sScoreTag);
    SDL_FreeSurface(sScore);

    delete bBack;
    delete input;
}
