#include <iostream>
#include <SDL/SDL.h>
#include <SDL/SDL_ttf.h>
#include <string>

#include "cStringInput.h"
#include "functions.h"

// Deze class is gebaseerd op de class gedemonstreerd in de tutorial van LazyFoo,
// te vinden op http://lazyfoo.net/SDL_tutorials/lesson23/index.php

cStringInput::cStringInput(TTF_Font* font, int r, int g, int b) {
    renderFont = font;
    clr = {r, g, b};

    txt = NULL;
    inputStr = "";

    SDL_EnableUNICODE( SDL_ENABLE );
}

cStringInput::~cStringInput() {
    if (txt != NULL) {
        SDL_FreeSurface(txt);
    }

    SDL_EnableUNICODE(SDL_DISABLE);
}

int cStringInput::logic(SDL_Event* pEvent) {
    if (pEvent->type == SDL_KEYDOWN) {
        std::string t = inputStr;

        if (inputStr.length() < 19) {
            // Space
            if (pEvent->key.keysym.unicode == (Uint16)' ') {
                inputStr += (char)pEvent->key.keysym.unicode;
            } else if((pEvent->key.keysym.unicode >= (Uint16)'0') && (pEvent->key.keysym.unicode <= (Uint16)'9' ) ) { // 0-9
                inputStr += (char)pEvent->key.keysym.unicode;
            } else if((pEvent->key.keysym.unicode >= (Uint16)'A') && (pEvent->key.keysym.unicode <= (Uint16)'Z')) { // A-Z
                inputStr += (char)pEvent->key.keysym.unicode;
            } else if((pEvent->key.keysym.unicode >= (Uint16)'a') && (pEvent->key.keysym.unicode <= (Uint16)'z')) { // a-z
                inputStr += (char)pEvent->key.keysym.unicode;
            }
        }

        // Backspace
        if(pEvent->key.keysym.sym == SDLK_BACKSPACE && inputStr.length() != 0) {
            inputStr.erase(inputStr.length() - 1);
        }

        if (t != inputStr) {
            SDL_FreeSurface(txt);

            txt = TTF_RenderText_Blended(renderFont, inputStr.c_str(), clr);
        }
    }
}

int cStringInput::render(SDL_Surface* dst, int x, int y) {
    if (txt != NULL) {
        applySurface(txt, dst, x, y);
    }
}

SDL_Surface* cStringInput::gSurface() {
    return txt;
}

std::string cStringInput::gInput() {
    return inputStr;
}
