// Includes I didn't make myself
#include <SDL/SDL.h>

// Includes I did make myself
#include "cHighscores.h"
#include "gamestate.h"
#include "gamestates.h"
#include "globals.h"

int cGameState::input() {
    while (SDL_PollEvent(&event)) {
        if (event.type == SDL_QUIT) {
            gm->setNextState(STATE_EXIT);
        }
    }

    this->mouseState = SDL_GetMouseState(&this->mX, &this->mY);
    this->keyState = SDL_GetKeyState(NULL);

    return 0;
}

// ----------------------------------------------------------------------------------------------

cGameMan::cGameMan(int startState) {
    switch (startState) {
        case STATE_INTRO:
            this->currState = new gsIntro();
            break;
        case STATE_MENU:
            this->currState = new gsMenu();
            break;
        case STATE_GAME:
            this->currState = new gsGame();
            break;
        case STATE_SCORES:
            this->currState = new gsScores();
            break;
        case STATE_HOWTO:
            this->currState = new gsHowTo();
            break;
        case STATE_ABOUT:
            this->currState = new gsAbout();
            break;
        default:
            this->currState = new gsIntro();
            break;
    }

    this->stateID = startState;
    this->nextState = STATE_NULL;

    params = new int[2];
    params[0] = 2;
    params[1] = 0;

    hs = new cHighscores();
}

cGameMan::~cGameMan() {
    delete params;
    delete hs;
}

int cGameMan::setNextState(int targetState) {
    if (this->nextState != STATE_EXIT) {
        this->nextState = targetState;
    }

    return 0;
}

int cGameMan::changeState() {
    if (this->nextState != STATE_NULL) {
        if (this->nextState != STATE_EXIT) {
            delete this->currState;

            switch (this->nextState) {
                case STATE_INTRO:
                    this->currState = new gsIntro();
                    break;
                case STATE_MENU:
                    this->currState = new gsMenu();
                    break;
                case STATE_GAME:
                    this->currState = new gsGame();
                    break;
                case STATE_SCORES:
                    this->currState = new gsScores();
                    break;
                case STATE_HOWTO:
                    this->currState = new gsHowTo();
                    break;
                case STATE_ABOUT:
                    this->currState = new gsAbout();
                    break;
                default:
                    this->currState = new gsIntro();
                    break;
            }

            this->stateID = this->nextState;
            this->nextState = STATE_NULL;
        } else {
            this->stateID = STATE_EXIT;
        }
    }

    return 0;
}

int cGameMan::getState() {
    return this->stateID;
}
