#include <SDL/SDL.h>

#include "button.h"
#include "cControls.h"
#include "cCountdown.h"
#include "cGame.h"
#include "cGameOver.h"
#include "checkboxes.h"
#include "cPaused.h"
#include "gamestate.h"

class gsAbout : public cGameState {
public:
    gsAbout();
    ~gsAbout();

    int logic();
    int render();

private:
    cButton* tB;
    SDL_Surface* about;

} ;

const int H_HELP = 1;
const int H_DUMMIES = 2;
const int H_CONTROLS = 3;
const int H_GAME = 4;
const int H_SCORE1 = 5;
const int H_SCORE2 = 6;

class gsHowTo : public cGameState {
public:
    gsHowTo();
    ~gsHowTo();

    int logic();
    int render();

private:
    cButton* bBack;
    cButton* bLeft;
    cButton* bRight;

    int prevBL;
    int prevBR;

    SDL_Surface* sHeader;
    SDL_Surface* sHelp;
    SDL_Surface* sDummies;
    SDL_Surface* sInGame;
    SDL_Surface* sHighscore1;
    SDL_Surface* sHighscore2;

    cControls* controls;

    std::string headers[6];
    int state;
} ;

class gsScores : public cGameState {
public:
    gsScores();
    ~gsScores();

    int logic();
    int render();

private:
    cButton* tB;

} ;

enum snakeGS {
    GM_NULL = 0,
    GM_GAME,
    GM_COUNTDOWN,
    GM_PAUSED,
    GM_OVER
} ;


class gsGame : public cGameState {
public:
    gsGame();
    ~gsGame();

    int logic();
    int render();
    int input();

private:
    snakeGS currState;
    snakeGS nextState;

    cGame* stGame;
    cCountdown* stCountdown;
    cPaused* stPaused;
    cGameOver* stOver;

    int score;

} ;

class gsMenu : public cGameState {
public:
    int logic();
    int render();

    gsMenu();
    ~gsMenu();

private:
    cButton* bPlay;
    cButton* bScores;
    cButton* bHelp;
    cButton* bAbout;
    cButton* bExit;

    cCheckboxes* cbDifficulty;
    cCheckboxes* cbWalls;

    SDL_Surface* sTagDiff;
    SDL_Surface* sTagEs;
    SDL_Surface* sTagMed;
    SDL_Surface* sTagHrd;
    SDL_Surface* sTagWalls;
    SDL_Surface* sTagSettings;
    SDL_Surface* sHeader;
    SDL_Surface* sBox;
} ;

class gsIntro : public cGameState {
public:
    int logic();
    int render();

    gsIntro();
    ~gsIntro();
private:
    cButton* bTest;
    // cCheckboxes* cbTest;

    cSnake* snake;
    eDirection dir;
    int lastChange;
    int delay;
} ;
