#include <SDL/SDL.h>
#include <string>

#include "button.h"
#include "functions.h"
#include "gamestates.h"
#include "globals.h"

int gsGame::logic() {
    int ti = 0;
    std::string tS = "";

    switch (currState) {
        case GM_GAME:
            ti = stGame->logic(keyState, mX, mY, mouseState);
            if (ti == 1) {
                nextState = GM_PAUSED;
                stGame->pause();
                // gm->setNextState(STATE_EXIT); HIERO
            } else if (ti == 2) {
                nextState = GM_OVER;
            }

            break;
        case GM_COUNTDOWN:
            if (stCountdown->logic() == 1) {
                nextState = GM_GAME;
                stGame->resume();
            }

            break;
        case GM_PAUSED:
            ti = stPaused->logic(mX, mY, mouseState);

            if (ti == 1) {
                nextState = GM_COUNTDOWN;
            } else if (ti == 2) {
                gm->setNextState(STATE_MENU);
            }

            break;
        case GM_OVER:
            if (keyState[SDLK_ESCAPE]) {
                gm->setNextState(STATE_MENU);
            }

            if (stOver->logic(mX, mY, mouseState, &tS) == 1) {
                gm->setNextState(STATE_MENU);
                gm->hs->addScore(tS, score);
            }
            break;
    }

    if (nextState != GM_NULL) {
        switch (nextState) {
            case GM_GAME:
                delete stCountdown;
                break;
            case GM_COUNTDOWN:
                stCountdown = new cCountdown();
                break;
            case GM_PAUSED:
                // Niets?
                break;
            case GM_OVER:
                // Aww jammer dit is uw score!
                stOver = new cGameOver(score);
                break;
        }

        currState = nextState;
        nextState = GM_NULL;
    }

    return 0;
}

int gsGame::render() {
    fresh(screen);

    switch (currState) {
        case GM_GAME:
            stGame->render();
            break;
        case GM_COUNTDOWN:
            stCountdown->render(stGame);
            break;
        case GM_PAUSED:
            stPaused->render(stGame);
            break;
        case GM_OVER:
            stOver->render(stGame);
            break;
    }

    SDL_Flip(screen);

    return 0;
}

int gsGame::input() {
    while (SDL_PollEvent(&event)) {
        if (event.type == SDL_QUIT) {
            gm->setNextState(STATE_EXIT);
        }

        if (stOver != NULL) {
            stOver->input->logic(&event);
        }
    }

    this->mouseState = SDL_GetMouseState(&this->mX, &this->mY);
    this->keyState = SDL_GetKeyState(NULL);

    return 0;
}

gsGame::gsGame() {
    stPaused = NULL;
    stCountdown = NULL;
    stGame = NULL;

    currState = GM_COUNTDOWN;
    nextState = GM_NULL;
    score = 0;

    stCountdown = new cCountdown();
    stGame = new cGame(&score, gm->params[0], gm->params[1]);
    stPaused = new cPaused();

    stGame->pause();

    stOver = NULL;
}

gsGame::~gsGame() {
    /*if (stGame != NULL) {*/delete stGame; //
    if (currState == GM_COUNTDOWN) {delete stCountdown;} // HIER???
    /*if (stPaused != NULL) {*/delete stPaused;
    if (currState == GM_OVER) {delete stOver;}
}
