#include <SDL/SDL.h>

#include "button.h"
#include "cControls.h"
#include "constants.h"
#include "functions.h"
#include "gamestates.h"
#include "globals.h"

int gsHowTo::logic() {
    int ti;

    if (bBack->logic(mX, mY, mouseState) == B_CLICK) {
        gm->setNextState(STATE_MENU);
    }

    if (state != H_HELP) {
        ti = bLeft->logic(mX, mY, mouseState);
        if (prevBL != B_CLICK && ti == B_CLICK) {
            state--;
            if (state < 1) state = 1;
        }
        prevBL = ti;
    }

    if (state != H_SCORE2) {
        ti = bRight->logic(mX, mY, mouseState);
        if (prevBR != B_CLICK && ti == B_CLICK) {
            state++;
            if (state > 6) state = 6;
        }
        prevBR = ti;
    }

    SDL_FreeSurface(sHeader);
    sHeader = TTF_RenderText_Shaded(fSpecial, headers[state-1].c_str(), clrBlack, clrWhite);

    switch (state) {
        case H_HELP:
            // Alleen een plaatje
            break;
        case H_DUMMIES:
            // 101
            break;
        case H_CONTROLS:
            controls->logic();
            break;
        case H_GAME:
            break;
        case H_SCORE1:
            break;
        case H_SCORE2:
            break;
    }

    return 0;
}

int gsHowTo::render() {
    fresh(screen);

    bBack->render();

    bLeft->render();

    bRight->render();

    applySurface(sHeader, screen, (SCR_W - sHeader->w) / 2, 0);

    switch (state) {
        case H_HELP:
            applySurface(sHelp, screen, 3, 36);
            break;
        case H_DUMMIES:
            applySurface(sDummies, screen, 0, 0);
            break;
        case H_CONTROLS:
            controls->render();
            break;
        case H_GAME:
            applySurface(sInGame, screen, 0, 0);
            break;
        case H_SCORE1:
            applySurface(sHighscore1, screen, 0, 0);
            break;
        case H_SCORE2:
            applySurface(sHighscore2, screen, 0, 0);
            break;
    }

    na();

    SDL_Flip(screen);

    return 0;
}

gsHowTo::gsHowTo() {
    bBack = new cButton("Terug", 5, 560, false, fNormal, B_VISIBLE, B_STANDARD);
    bLeft = new cButton("<-", 0, 0, false, fSpecial, B_VISIBLE, B_STANDARD);
    bRight = new cButton("->", 450, 0, false, fSpecial, B_VISIBLE, B_STANDARD);

    state = H_HELP;

    prevBL = B_NEUTRAL;
    prevBR = B_NEUTRAL;

    headers[0] = "Help";
    headers[1] = "Snake+ 101";
    headers[2] = "Besturing";
    headers[3] = "Spelscherm";
    headers[4] = "Highscore";
    headers[5] = "Highscore";

    sHeader = TTF_RenderText_Shaded(fSpecial, headers[state-1].c_str(), clrBlack, clrWhite);
    sHelp = loadImage("Media/help.png");
    sDummies = loadImage("Media/101.png");
    sInGame = loadImage("Media/gamehelp.png");
    sHighscore1 = loadImage("Media/highscore1.png");
    sHighscore2 = loadImage("Media/highscore2.png");

    controls = new cControls();
}

gsHowTo::~gsHowTo() {
    delete bBack;
    delete bLeft;
    delete bRight;

    SDL_FreeSurface(sHeader);
    SDL_FreeSurface(sHelp);
    SDL_FreeSurface(sDummies);
    SDL_FreeSurface(sInGame);
    SDL_FreeSurface(sHighscore1);
    SDL_FreeSurface(sHighscore2);
}
