#include <SDL/SDL.h>
#include <SDL/SDL_ttf.h>

#include "button.h"
#include "cHighscores.h"
#include "functions.h"
#include "gamestates.h"
#include "globals.h"

int gsMenu::logic() {
    cbDifficulty->logic(mX, mY, mouseState);

    cbWalls->logic(mX, mY, mouseState);

    if (bPlay->logic(mX, mY, mouseState) == B_CLICK) {
        gm->setNextState(STATE_GAME);

        gm->params[0] = cbDifficulty->getSelected();
        gm->params[1] = cbWalls->getSelected();
    }

    if (bScores->logic(mX, mY, mouseState) == B_CLICK) {
        gm->setNextState(STATE_SCORES);
        cHighscores* hs;
        hs = new cHighscores();
        hs->render();
        delete hs;
    }

    if (bHelp->logic(mX, mY, mouseState) == B_CLICK) {
        gm->setNextState(STATE_HOWTO);
    }

    if (bAbout->logic(mX, mY, mouseState) == B_CLICK) {
        gm->setNextState(STATE_ABOUT);
    }

    if (bExit->logic(mX, mY, mouseState) == B_CLICK) {
        gm->setNextState(STATE_EXIT);
    }

    return 0;
}

int gsMenu::render() {
    fresh(screen);
    bPlay->render();
    bScores->render();
    bHelp->render();
    bAbout->render();
    bExit->render();

    applySurface(sHeader, screen, 10, 10);

    applySurface(sTagSettings, screen, 20, 277 + 23);
    applySurface(sBox, screen, 20, 315 + 20);

    applySurface(sTagDiff, screen, 40, 330 + 20);
    applySurface(sTagEs, screen, 40, 395 + 20);
    applySurface(sTagMed, screen, 140, 395 + 20);
    applySurface(sTagHrd, screen, 240, 395 + 20);
    cbDifficulty->render();

    if (cbWalls->getSelected()) {
        sTagWalls = TTF_RenderText_Shaded(fTagP, "Muren aan", clrBlack, clrWhite);
    } else {
        sTagWalls = TTF_RenderText_Shaded(fTagP, "Muren uit", clrBlack, clrWhite);
    }
    applySurface(sTagWalls, screen, 75, 442 + 20);
    SDL_FreeSurface(sTagWalls);
    cbWalls->render();

    na();

    SDL_Flip(screen);

    return 0;
}

gsMenu::gsMenu() {
    TTF_Font* fT = fNormal;

    int start = 300;
    int stp = 60;

    bPlay = new cButton("Speel", 0, start, true, fT, B_VISIBLE, B_STANDARD);
    bScores = new cButton("Scores", 0, start + stp, true, fT, B_VISIBLE, B_STANDARD);
    bHelp = new cButton("Help", 0, start + stp * 2, true, fT, B_VISIBLE, B_STANDARD);
    bAbout = new cButton("Over", 0, start + stp * 3, true, fT, B_VISIBLE, B_STANDARD);
    bExit = new cButton("Sluiten", 0, start + stp * 4, true, fT, B_VISIBLE, B_STANDARD);

    cbDifficulty = new cCheckboxes(40, 360 + 20, 100, true, 3, 30, 4);
    cbWalls = new cCheckboxes(40, 440 + 20, 0, true, 1, 30, 4);

    cbDifficulty->setSelected(gm->params[0]);
    cbWalls->setSelected(gm->params[1]);

    fT = fTagP;
    sTagDiff = TTF_RenderText_Shaded(fT, "Moeilijkheidsgraad", clrBlack, clrWhite);
    // sTagWalls = TTF_RenderText_Shaded(fT, "Muren aan/uit", clrBlack, clrWhite);

    fT = fTag;
    sTagEs = TTF_RenderText_Shaded(fT, "Makkelijk", clrBlack, clrWhite);
    sTagMed = TTF_RenderText_Shaded(fT, "Gemiddeld", clrBlack, clrWhite);
    sTagHrd = TTF_RenderText_Shaded(fT, "Moeilijk", clrBlack, clrWhite);

    sHeader = loadImage("Media/header.png");

    sTagSettings = TTF_RenderText_Shaded(fNormal, "Spelinstellingen", clrBlack, clrWhite);
    sBox = loadImage("Media/boxMenu.png");
}

gsMenu::~gsMenu() {
    delete bPlay;
    delete bScores;
    delete bHelp;
    delete bAbout;
    delete bExit;

    delete cbDifficulty;
    delete cbWalls;

    SDL_FreeSurface(sTagDiff);

    SDL_FreeSurface(sTagEs);
    SDL_FreeSurface(sTagMed);
    SDL_FreeSurface(sTagHrd);

    // SDL_FreeSurface(sTagWalls);

    SDL_FreeSurface(sHeader);

    SDL_FreeSurface(sBox);
    SDL_FreeSurface(sTagSettings);
}
